calorine
========

`calorine <https://xkcd.com/910/>`_ is a Python library for managing `GPUMD <https://gpumd.zheyongfan.org/>`_ simulations.
The documentation can be found at https://calorine.materialsmodeling.org/.
